@@ -10,15 +10,12 @@ from base64 import b64encode
 from hashlib import md5
 from os.path import abspath,dirname,join
 from mako.template import Template
+from template import TEMPALTE_QUERY, TEMPALTE_PAY
 
 PWD = dirname(abspath(__file__))
 
 
-with open(join(PWD,"pay.xml")) as PAY:
-    TEMPALTE_PAY = Template(PAY.read(),input_encoding="utf-8")
-
-with open(join(PWD,"query.xml")) as QUERY:
-    TEMPALTE_QUERY = Template(QUERY.read(),input_encoding="utf-8")
+TEMPALTE_PAY, TEMPALTE_QUERY = map(lambda x:Template(x,input_encoding="utf-8"), (TEMPALTE_PAY, TEMPALTE_QUERY))
 
 class Tenpay(object):
 
@@ -52,6 +49,4 @@ class Tenpay(object):
 
 
 if __name__ == "__main__":
-    tenpay = Tenpay(1900000107,"82d2f8b9fd7695aec51415ab2900a755", join(PWD,'new.pem'))
-    tenpay.pay( op_code=1013, op_name="batch_draw", op_user='1900000107', op_passwd=111111, op_time=20110823105511000, sp_id=1900000107, package_id='asfffwe', total_num=2, total_amt=3, client_ip="10.6.35.42", record_set = ( ('1', '6225887811111111', '1001', u'张三', '1', '1', '20', '755', u'招商银行深圳泰然金谷支行', u'代付测试', '13631511111'), ('2', '6225887822222222', '1001', u'李四', '2', '1', '20', '755', u'招商银行深圳泰然金谷支行', '', '')))
-    #tenpay.query( op_code=1014, op_name="batch_draw_query", service_version='1.1', op_user=1900000107, op_passwd=111111, op_time=20110823105511000, sp_id=1900000107, package_id=20110823001, client_ip='10.6.35.42')  
+    print TEMPALTE_PAY.render(op_code=1013, op_name="batch_draw", op_user='1900000107', op_passwd=111111, op_time=20110823105511000, sp_id=1900000107, package_id='asfffwe', total_num=2, total_amt=3, client_ip="10.6.35.42", record_set = ( ('1', '6225887811111111', '1001', u'张三', '1', '1', '20', '755', u'招商银行深圳泰然金谷支行', u'代付测试', '13631511111'), ('2', '6225887822222222', '1001', u'李四', '2', '1', '20', '755', u'招商银行深圳泰然金谷支行', '', '')))
